/** \file expCconf.h
 *
 *   atMegaExperimental project configuration settings
 *
 *   This file contains some definitions concerning software and hardware
 *   configuration. These settings influence the compilation and building
 *   process and can't be changed later at runtime.
 *
 *  Copyright (c) 2014  Albrecht Weinert, Bochum
 * &nbsp; <<a href="http://a-weinert.de">a-weinert.de</a>>
 *  $Revision: 1 $
 *  $Date: 2017-01-25 11:27:06 +0000 (Wed, 25 Jan 2017) $
 */
//  SVN last change by $Author: albrecht $


#ifndef EXP_CONF_H
#define EXP_CONF_H


#include <avr/io.h>

#include <stdint.h>
#include "arch/config.h"
#include "we-aut_sys/ll_common.h"

//--- platform specific include     ----------------------------------------

#define __hexder(x) #x                           // it's a kind
#define _hexder(x) __hexder(arch/expConf_##x.h) // of
#define hexder(x) _hexder(x)                   // magic
#include hexder(PLATFORM)



/** The project's name
 *
 *  <b> &nbsp; See also: &nbsp; </b> \ref SYST_DAT
 *  \showinitializer
 */
#define PROJECT "atMegaExperimental"


/** The runtime's revision
 *
 *  \internal To be correct: This is the SVN revision text of this file. <br />
 *  The value is a "quoted" string like "$Revision: 1 $".
 *
 *  <b> &nbsp; See also: &nbsp; </b> \ref SYST_DAT  \ref SYST_MOD
 *  \showinitializer
 */
#define PROJECT_REV "$Revision: 1 $"
   //                0123456789.123456

/** This file's last modification date (SVN)
 *
 *  This file's subversion (SVN) modification date and
 *  \ref SYST_REV "revision number" are taken as the
 *  \ref intro_sec "weAutSys" runtime's revision data.
 *
 *  The value is a "quoted" string.
 *
 *  <b> &nbsp; See also: &nbsp; </b> \ref DEFAULT_START_TIME  \ref SYST_REV
 *     \ref SYST_MOD
 *  \showinitializer
 */
#define PROJ_DAT "$Date: 2017-01-25 11:27:06 +0000 (Wed, 25 Jan 2017) $"




// Set level (0 off 1 low 2 medium 3 high) for .................

#if compileDebugs

#define DEBUG_ETH  3  //!< Ethernet driver debugging \showinitializer
#define DEBUG_DHCP 3  //!< DHCP debugging \showinitializer
#define DEBUG_NTP  3  //!< NTP debugging \showinitializer
#define DEBUG_TEL  3  //!< Telnet debugging \showinitializer
#define DEBUG_MOD  3  //!< Modbus debugging \showinitializer
#define DEBUG_ARP  3  //!< ARP debugging \showinitializer
#define DEBUG_ApL  3  //!< Application layer debugging \showinitializer
#define DEBUG_EEP  3  //!< EEPROM debugging \showinitializer
#define DEBUG_UART 3  //!< UART (input) debugging \showinitializer
#define DEBUG_SMC  3  //!< SMC (small memory card) debugging \showinitializer

#endif

/** @} */ // Doxygen addtogroup swDebaid
/** @} */ // Doxygen addtogroup llSySer


#endif /* EXP_CONF_H */
